.. _examples:

========
Examples
========

Here, we look at example use cases for the library, and show how to use it in python. Many of these are
copied straight from the unit test cases, so you can always check there to see how everything hooks up.


.. _example_schema:
Example Schema
==============

.. tabs::

   .. code-tab:: py

        import numpy as np
        import es

        def main():
            pass
